Index: /WAeUP_SRP/trunk/Academics.py
===================================================================
--- /WAeUP_SRP/trunk/Academics.py	(revision 439)
+++ /WAeUP_SRP/trunk/Academics.py	(revision 440)
@@ -39,4 +39,5 @@
     portal_type = meta_type
     security = ClassSecurityInfo()
+    use_catalog_for_folder_contents = True
 
     security.declareProtected(View,"Title")
Index: /WAeUP_SRP/trunk/Students.py
===================================================================
--- /WAeUP_SRP/trunk/Students.py	(revision 439)
+++ /WAeUP_SRP/trunk/Students.py	(revision 440)
@@ -33,5 +33,4 @@
     portal_type = meta_type
     security = ClassSecurityInfo()
-    use_catalog_for_folder_contents = True
 
     security.declareProtected(ModifyPortalContent,"loadFullTimeStudentsFromCSV")###(
@@ -470,58 +469,4 @@
 ###)
 
-class StudentDocuments(CPSDocument): ###(
-    """
-    WAeUP Student container for the various student data
-    """
-    meta_type = 'StudentDocuments'
-    portal_type = meta_type
-    security = ClassSecurityInfo()
-
-    security.declareProtected(View,"Title")
-    def Title(self):
-        """compose title"""
-        content = self.getContent()
-        return "Scanned Documents"
-
-
-InitializeClass(StudentDocuments)
-
-def addStudentDocuments(container, id, REQUEST=None, **kw):
-    """Add a Students documents"""
-    ob = StudentDocuments(id, **kw)
-    return CPSBase_adder(container, ob, REQUEST=REQUEST)
-
-###)
-
-class Jamb(CPSDocument): ###(
-    """
-    WAeUP Jamb containing the courses and students
-    """
-    meta_type = 'Jamb'
-    portal_type = meta_type
-    security = ClassSecurityInfo()
-
-    security.declareProtected(View,"Title")
-    def Title(self):
-        """compose title"""
-        content = self.getContent()
-        return "JAMB Data for %s %s" % (content.firstname,content.lastname)
-
-    security.declareProtected(View,"setOwnership")
-    def setOwnership(self,member_id):
-        """set ownership"""
-        pm = getattr(self,'portal_membership')
-        member = pm.getMemberById(member_id)
-        self.changeOwnership(member)
-
-InitializeClass(Jamb)
-
-def addJamb(container, id, REQUEST=None, **kw):
-    """Add a Jamb."""
-    ob = Jamb(id, **kw)
-    return CPSBase_adder(container, ob, REQUEST=REQUEST)
-
-###)
-
 class StudyLevel(CPSDocument): ###(
     """
@@ -531,4 +476,10 @@
     portal_type = meta_type
     security = ClassSecurityInfo()
+
+    security.declareProtected(View,"Title")
+    def Title(self):
+        """compose title"""
+        return "Level %s" % self.aq_parent.getId()
+    
 
 InitializeClass(StudyLevel)
@@ -558,2 +509,50 @@
 ###)
 
+class ScratchCardBatchesFolder(CPSDocument): ###(
+    """
+    WAeUP Student container for the various student data
+    """
+    meta_type = 'ScratchCardBatchesFolder'
+    portal_type = meta_type
+    security = ClassSecurityInfo()
+
+    security.declareProtected(View,"Title")
+    def Title(self):
+        """compose title"""
+        return "Pin Batches"
+
+
+InitializeClass(ScratchCardBatchesFolder)
+
+def addScratchCardBatchesFolder(container, id, REQUEST=None, **kw):
+    """Add a Students personal data."""
+    ob = ScratchCardBatchesFolder(id, **kw)
+    return CPSBase_adder(container, ob, REQUEST=REQUEST)
+
+###)
+
+from Products.WAeUP_SRP.WAeUPTables import PinTable
+
+class ScratchCardBatch(CPSDocument): ###(
+    """
+    WAeUP Student container for the various student data
+    """
+    meta_type = 'ScratchCardBatch'
+    portal_type = meta_type
+    security = ClassSecurityInfo()
+
+    security.declareProtected(View,"Title")
+    def Title(self):
+        """compose title"""
+        doc = self.getContent()
+        return "Pin Batch %s BatchNo %d" % (doc.prefix, doc.batch_no)
+
+
+InitializeClass(ScratchCardBatch)
+
+def addScratchCardBatch(container, id, REQUEST=None, **kw):
+    """Add a Students personal data."""
+    ob = ScratchCardBatch(id, **kw)
+    return CPSBase_adder(container, ob, REQUEST=REQUEST)
+
+###)
Index: /WAeUP_SRP/trunk/WAeUPTables.py
===================================================================
--- /WAeUP_SRP/trunk/WAeUPTables.py	(revision 439)
+++ /WAeUP_SRP/trunk/WAeUPTables.py	(revision 440)
@@ -77,4 +77,20 @@
 InitializeClass(AccommodationTable)
 
+class PinTable(WAeUPTable):
+    
+    meta_type = 'WAeUP Pin Tool'
+    
+    def __init__(self):
+        WAeUPTable.__init__(self, 'portal_pins')
+
+    def addRecord(self, **data):
+        # The uid is the same as "bed".
+        uid = data['bed']
+        self.catalog_object(dict2ob(data), uid=uid)
+        return uid
+
+
+InitializeClass(PinTable)
+
 # BBB:
 AccomodationTable = AccommodationTable
Index: /WAeUP_SRP/trunk/Widgets.py
===================================================================
--- /WAeUP_SRP/trunk/Widgets.py	(revision 439)
+++ /WAeUP_SRP/trunk/Widgets.py	(revision 440)
@@ -159,5 +159,5 @@
             value = datastructure[widget_id].upper()
             err = 0
-            if value.split() > 1:
+            if len(value.split()) > 1:
                 err = 'Invalid Id (Id contains space(s)' 
             elif hasattr(self.aq_parent,value):
Index: /WAeUP_SRP/trunk/profiles/catalog.xml
===================================================================
--- /WAeUP_SRP/trunk/profiles/catalog.xml	(revision 439)
+++ /WAeUP_SRP/trunk/profiles/catalog.xml	(revision 440)
@@ -1,5 +1,10 @@
 <?xml version="1.0"?>
 <object name="portal_catalog" meta_type="CMF Catalog">
- <column value="credits"/>
- <column value="passmark"/>
+ <property name="title"></property>
+ <index name="jamb_reg_no" meta_type="FieldIndex">
+  <indexed_attr value="jamb_reg_no"/>
+ </index>
+ <index name="matric_no" meta_type="FieldIndex">
+  <indexed_attr value="matric_no"/>
+ </index>
 </object>
Index: /WAeUP_SRP/trunk/profiles/default/layouts/scratch_card_batch.xml
===================================================================
--- /WAeUP_SRP/trunk/profiles/default/layouts/scratch_card_batch.xml	(revision 440)
+++ /WAeUP_SRP/trunk/profiles/default/layouts/scratch_card_batch.xml	(revision 440)
@@ -0,0 +1,61 @@
+<?xml version="1.0"?>
+<object name="scratch_card_batch" meta_type="CPS Layout">
+ <property name="layout_create_method"></property>
+ <property name="layout_edit_method"></property>
+ <property name="layout_view_method"></property>
+ <property name="style_prefix">layout_default_</property>
+ <property name="flexible_widgets"/>
+ <property name="validate_values_expr"></property>
+ <widget name="cost" meta_type="Float Widget">
+  <property name="title">Cost</property>
+  <property name="fields">
+   <element value="cost"/>
+  </property>
+  <property name="is_required">True</property>
+  <property name="label">Cost</property>
+  <property name="label_edit">Cost</property>
+  <property name="readonly_layout_modes"/>
+  <property name="hidden_layout_modes"/>
+  <property name="hidden_readonly_layout_modes"/>
+ </widget>
+ <widget name="no_of_pins" meta_type="Int Widget">
+  <property name="title">Nr of Pins </property>
+  <property name="fields">
+   <element value="no_of_pins"/>
+  </property>
+  <property name="is_required">True</property>
+  <property name="label">Nr of Pins </property>
+  <property name="label_edit">Nr of Pins </property>
+  <property name="readonly_layout_modes"/>
+  <property name="hidden_layout_modes"/>
+  <property name="hidden_readonly_layout_modes"/>
+  <property name="min_value">1000</property>
+  <property name="max_value">100000</property>
+ </widget>
+ <widget name="prefix" meta_type="String Widget">
+  <property name="title">Prefix</property>
+  <property name="fields">
+   <element value="prefix"/>
+  </property>
+  <property name="is_required">True</property>
+  <property name="label">Prefix</property>
+  <property name="label_edit">Prefix</property>
+  <property name="readonly_layout_modes"/>
+  <property name="hidden_layout_modes"/>
+  <property name="hidden_readonly_layout_modes"/>
+  <property name="display_width">3</property>
+  <property name="size_max">3</property>
+ </widget>
+ <widget name="sold_by" meta_type="String Widget">
+  <property name="title">Sold by</property>
+  <property name="fields">
+   <element value="sold_by"/>
+  </property>
+  <property name="label">Sold by</property>
+  <property name="label_edit">Sold by</property>
+  <property name="readonly_layout_modes"/>
+  <property name="hidden_layout_modes"/>
+  <property name="hidden_readonly_layout_modes"/>
+ </widget>
+ <table/>
+</object>
Index: /WAeUP_SRP/trunk/profiles/default/layouts/study_level.xml
===================================================================
--- /WAeUP_SRP/trunk/profiles/default/layouts/study_level.xml	(revision 439)
+++ /WAeUP_SRP/trunk/profiles/default/layouts/study_level.xml	(revision 440)
@@ -7,59 +7,13 @@
  <property name="flexible_widgets"/>
  <property name="validate_values_expr"></property>
- <widget name="Title" meta_type="String Widget">
-  <property name="title">Title</property>
+ <widget name="code" meta_type="String Widget">
+  <property name="title">Level No</property>
   <property name="fields">
-   <element value="Title"/>
-  </property>
-  <property name="label">Level Nr</property>
-  <property name="label_edit">Level Nr</property>
-  <property name="readonly_layout_modes"/>
-  <property name="hidden_layout_modes"/>
-  <property name="hidden_readonly_layout_modes"/>
-  <property name="display_width">40</property>
- </widget>
- <widget name="sc_id" meta_type="String Widget">
-  <property name="title">SC ID</property>
-  <property name="fields">
-   <element value="sc_id"/>
-  </property>
-  <property name="label">Card Serial Number </property>
-  <property name="label_edit">Card Serial Number</property>
-  <property name="description">Card Serial Number </property>
-  <property
-     name="help">This can be found on the bottom right of the reverse side of your Scratch Card</property>
-  <property name="readonly_layout_modes"/>
-  <property name="hidden_layout_modes"/>
-  <property name="hidden_readonly_layout_modes"/>
-  <property name="hidden_if_expr">python:1</property>
-  <property name="display_width">10</property>
- </widget>
- <widget name="sc_pin" meta_type="Scratchcard Pin Widget">
-  <property name="title">SC PIN</property>
-  <property name="fields">
-   <element value="sc_pin"/>
+   <element value="code"/>
   </property>
   <property name="is_required">True</property>
-  <property name="label">Enter  PIN</property>
-  <property
-     name="label_edit">Enter Scratchcard Pin with the value above</property>
-  <property
-     name="help">Please enter a Scratchcard Pin valid for Registration of Next Level</property>
+  <property name="label">Level No</property>
+  <property name="label_edit">Level No</property>
   <property name="readonly_layout_modes"/>
-  <property name="hidden_layout_modes"/>
-  <property name="hidden_readonly_layout_modes"/>
-  <property name="display_width">10</property>
-  <property name="size_max">10</property>
- </widget>
- <widget name="sc_value" meta_type="Float Widget">
-  <property name="title">Scratch card value</property>
-  <property name="fields">
-   <element value="sc_value"/>
-  </property>
-  <property name="label">Scratcard Value</property>
-  <property name="label_edit">Scratcard Value</property>
-  <property name="readonly_layout_modes">
-   <element value="create"/>
-  </property>
   <property name="hidden_layout_modes"/>
   <property name="hidden_readonly_layout_modes"/>
@@ -67,5 +21,5 @@
  <table>
   <row>
-   <cell name="Title"/>
+   <cell name="code"/>
   </row>
  </table>
Index: /WAeUP_SRP/trunk/profiles/default/pins.xml
===================================================================
--- /WAeUP_SRP/trunk/profiles/default/pins.xml	(revision 440)
+++ /WAeUP_SRP/trunk/profiles/default/pins.xml	(revision 440)
@@ -0,0 +1,11 @@
+<?xml version="1.0"?>
+<object name="portal_catalog" meta_type="CMF Catalog">
+ <column value="pin"/>
+ <column value="student"/>
+ <index name="pin" meta_type="FieldIndex">
+  <indexed_attr value="pin"/>
+ </index>
+ <index name="student" meta_type="FieldIndex">
+  <indexed_attr value="student"/>
+ </index>
+</object>
Index: /WAeUP_SRP/trunk/profiles/default/roots/campus.xml
===================================================================
--- /WAeUP_SRP/trunk/profiles/default/roots/campus.xml	(revision 439)
+++ /WAeUP_SRP/trunk/profiles/default/roots/campus.xml	(revision 440)
@@ -6,3 +6,4 @@
   <object name="accommodation" portal_type="AccoFolder" />
   <object name="students" portal_type="StudentsFolder" />
+  <object name="pins" portal_type="ScratchCardBatchesFolder" />
 </object>
Index: /WAeUP_SRP/trunk/profiles/default/roots/campus/pins.xml
===================================================================
--- /WAeUP_SRP/trunk/profiles/default/roots/campus/pins.xml	(revision 440)
+++ /WAeUP_SRP/trunk/profiles/default/roots/campus/pins.xml	(revision 440)
@@ -0,0 +1,4 @@
+<?xml version="1.0"?>
+<object name="pins">
+  <property name="Title">Pin Batches</property>
+</object>
Index: /WAeUP_SRP/trunk/profiles/default/schemas/scratch_card_batch.xml
===================================================================
--- /WAeUP_SRP/trunk/profiles/default/schemas/scratch_card_batch.xml	(revision 440)
+++ /WAeUP_SRP/trunk/profiles/default/schemas/scratch_card_batch.xml	(revision 440)
@@ -0,0 +1,10 @@
+<?xml version="1.0"?>
+<object name="scratch_card_batch" meta_type="CPS Schema">
+ <field name="batch_no" meta_type="CPS Int Field"/>
+ <field name="cost" meta_type="CPS Float Field"/>
+ <field name="no_of_pins" meta_type="CPS Int Field">
+  <property name="default_expr">python:1000</property>
+ </field>
+ <field name="prefix" meta_type="CPS String Field"/>
+ <field name="sold_by" meta_type="CPS String Field"/>
+</object>
Index: /WAeUP_SRP/trunk/profiles/default/schemas/study_level.xml
===================================================================
--- /WAeUP_SRP/trunk/profiles/default/schemas/study_level.xml	(revision 439)
+++ /WAeUP_SRP/trunk/profiles/default/schemas/study_level.xml	(revision 440)
@@ -1,15 +1,5 @@
 <?xml version="1.0"?>
 <object name="study_level" meta_type="CPS Schema">
- <field name="sc_id" meta_type="CPS String Field">
-  <property name="is_searchabletext">True</property>
-  <property name="acl_write_roles">SectionReader</property>
- </field>
- <field name="sc_pin" meta_type="CPS String Field">
-  <property name="is_searchabletext">True</property>
-  <property name="acl_write_roles">SectionReader</property>
- </field>
- <field name="sc_value" meta_type="CPS Float Field">
-  <property name="default_expr">python:1000.</property>
-  <property name="is_searchabletext">True</property>
- </field>
+ <field name="code" meta_type="CPS String Field"/>
 </object>
+
Index: /WAeUP_SRP/trunk/profiles/default/toolset.xml
===================================================================
--- /WAeUP_SRP/trunk/profiles/default/toolset.xml	(revision 439)
+++ /WAeUP_SRP/trunk/profiles/default/toolset.xml	(revision 440)
@@ -3,3 +3,5 @@
  <required tool_id="portal_accommodation"
            class="Products.WAeUP_SRP.WAeUPTables.AccommodationTable"/>
+ <required tool_id="portal_pins"
+           class="Products.WAeUP_SRP.WAeUPTables.PinTable"/>
 </tool-setup>
Index: /WAeUP_SRP/trunk/profiles/default/types/ScratchCardBatch.xml
===================================================================
--- /WAeUP_SRP/trunk/profiles/default/types/ScratchCardBatch.xml	(revision 440)
+++ /WAeUP_SRP/trunk/profiles/default/types/ScratchCardBatch.xml	(revision 440)
@@ -0,0 +1,41 @@
+<?xml version="1.0"?>
+<object name="ScratchCardBatch" meta_type="CPS Flexible Type Information"
+   xmlns:i18n="http://xml.zope.org/namespaces/i18n">
+ <property name="title">WAeUP Scratchcard Batch</property>
+ <property name="description"></property>
+ <property name="content_icon"></property>
+ <property name="content_meta_type">ScratchCardBatch</property>
+ <property name="product">WAeUP_SRP</property>
+ <property name="factory">addScratchCardBatch</property>
+ <property name="immediate_view">folder_view</property>
+ <property name="global_allow">True</property>
+ <property name="filter_content_types">True</property>
+ <property name="allowed_content_types"/>
+ <property name="allow_discussion">False</property>
+ <property name="cps_is_searchable">False</property>
+ <property name="cps_proxy_type">document</property>
+ <property name="cps_display_as_document_in_listing">True</property>
+ <property name="schemas">
+  <element value="scratch_card_batch"/>
+ </property>
+ <property name="layouts">
+  <element value="scratch_card_batch"/>
+ </property>
+ <property name="layout_clusters"/>
+ <property name="flexible_layouts"/>
+ <property name="storage_methods"/>
+ <property name="cps_is_portlet">False</property>
+ <alias from="(Default)" to="academics_contents"/>
+ <alias from="view" to="academics_contents"/>
+ <action title="Standard View" action_id="view" category="object"
+    condition_expr="python:object.getContent().memberIsOwner() or (member and 'SectionManager'in member.getRoles())"
+    url_expr="string:${object_url}/academics_contents" visible="True">
+  <permission value="View"/>
+ </action>
+ <action title="add Scratch Card Batch " action_id="new_entry"
+    category="object" condition_expr=""
+    url_expr="string:${object/absolute_url}/content_create?type_name=ScratchCard"
+    visible="True">
+  <permission value="Modify portal content"/>
+ </action>
+</object>
Index: /WAeUP_SRP/trunk/profiles/default/types/ScratchCardBatchesFolder.xml
===================================================================
--- /WAeUP_SRP/trunk/profiles/default/types/ScratchCardBatchesFolder.xml	(revision 440)
+++ /WAeUP_SRP/trunk/profiles/default/types/ScratchCardBatchesFolder.xml	(revision 440)
@@ -0,0 +1,42 @@
+<?xml version="1.0"?>
+<object name="ScratchCardBatchesFolder"
+   meta_type="CPS Flexible Type Information"
+   xmlns:i18n="http://xml.zope.org/namespaces/i18n">
+ <property name="title">WAeUP Scratchcard Batch</property>
+ <property name="description"></property>
+ <property name="content_icon"></property>
+ <property name="content_meta_type">ScratchCardBatchesFolder</property>
+ <property name="product">WAeUP_SRP</property>
+ <property name="factory">addScratchCardBatchesFolder</property>
+ <property name="immediate_view">folder_view</property>
+ <property name="global_allow">True</property>
+ <property name="filter_content_types">True</property>
+ <property name="allowed_content_types">
+  <element value="ScratchCardBatch"/>
+ </property>
+ <property name="allow_discussion">False</property>
+ <property name="cps_is_searchable">False</property>
+ <property name="cps_proxy_type">folder</property>
+ <property name="cps_display_as_document_in_listing">True</property>
+ <property name="schemas"/>
+ <property name="layouts"/>
+ <property name="layout_clusters"/>
+ <property name="flexible_layouts"/>
+ <property name="storage_methods"/>
+ <property name="cps_is_portlet">False</property>
+ <alias from="(Default)" to="academics_contents"/>
+ <alias from="create_do" to="scratch_card_batch_create_do"/>
+ <alias from="created" to="scratch_card_batch_created"/>
+ <alias from="view" to="academics_contents"/>
+ <action title="Standard View" action_id="view" category="object"
+    condition_expr="" url_expr="string:${object_url}/academics_contents"
+    visible="True">
+  <permission value="View"/>
+ </action>
+ <action title="add Scratch Card Batch " action_id="new_entry"
+    category="object" condition_expr=""
+    url_expr="string:${object/absolute_url}/content_create?type_name=ScratchCardBatch"
+    visible="True">
+  <permission value="Modify portal content"/>
+ </action>
+</object>
Index: /WAeUP_SRP/trunk/profiles/default/types/Semester.xml
===================================================================
--- /WAeUP_SRP/trunk/profiles/default/types/Semester.xml	(revision 439)
+++ /WAeUP_SRP/trunk/profiles/default/types/Semester.xml	(revision 440)
@@ -21,5 +21,6 @@
  <property name="cps_display_as_document_in_listing">True</property>
  <property name="schemas">
- </property>
+<element value="metadata"/>
+  </property>
  <property name="layouts"/>
  <property name="layout_clusters">
@@ -35,19 +36,4 @@
   <permission value="View"/>
  </action>
- <action title="Book Semester Courses" action_id="book_semester_courses"
-    category="object" condition_expr=""
-    url_expr="string:${object_url}/book_semester_courses" visible="False">
-  <permission value="Take ownership"/>
- </action>
- <action title="action_metadata" action_id="metadata" category="object"
-    condition_expr=""
-    url_expr="string:${object_url}/cpsdocument_metadata" visible="False">
-  <permission value="Modify portal content"/>
- </action>
- <action title="Delegate" action_id="localroles" category="object"
-    condition_expr="" url_expr="string:${object_url}/folder_localrole_form"
-    visible="False">
-  <permission value="Modify portal content"/>
- </action>
  <action title="Add Course" action_id="new_entry" category="object"
     condition_expr=""
Index: /WAeUP_SRP/trunk/profiles/default/types/StudentPersonal.xml
===================================================================
--- /WAeUP_SRP/trunk/profiles/default/types/StudentPersonal.xml	(revision 439)
+++ /WAeUP_SRP/trunk/profiles/default/types/StudentPersonal.xml	(revision 440)
@@ -13,5 +13,5 @@
  <property name="allowed_content_types"/>
  <property name="allow_discussion">False</property>
- <property name="cps_is_searchable">True</property>
+ <property name="cps_is_searchable">False</property>
  <property name="cps_proxy_type">document</property>
  <property name="cps_display_as_document_in_listing">True</property>
Index: /WAeUP_SRP/trunk/profiles/default/types/StudyLevel.xml
===================================================================
--- /WAeUP_SRP/trunk/profiles/default/types/StudyLevel.xml	(revision 439)
+++ /WAeUP_SRP/trunk/profiles/default/types/StudyLevel.xml	(revision 440)
@@ -8,5 +8,5 @@
  <property name="product">WAeUP_SRP</property>
  <property name="factory">addStudyLevel</property>
- <property name="immediate_view">folder_view</property>
+ <property name="immediate_view">academics_contents</property>
  <property name="global_allow">True</property>
  <property name="filter_content_types">True</property>
@@ -24,11 +24,10 @@
   <element value="study_level"/>
  </property>
- <property name="layout_clusters">
-  <element value=""/>
- </property>
+ <property name="layout_clusters"/>
  <property name="flexible_layouts"/>
  <property name="storage_methods"/>
  <property name="cps_is_portlet">False</property>
  <alias from="(Default)" to="academics_contents"/>
+ <alias from="create_do" to="waeup_document_create_do"/>
  <alias from="created" to="level_created"/>
  <alias from="view" to="academics_contents"/>
Index: /WAeUP_SRP/trunk/profiles/default/workflows.xml
===================================================================
--- /WAeUP_SRP/trunk/profiles/default/workflows.xml	(revision 439)
+++ /WAeUP_SRP/trunk/profiles/default/workflows.xml	(revision 440)
@@ -87,6 +87,9 @@
    <bound-workflow workflow_id="section_folder_wf"/>
   </type>
-  <type type_id="Workspace">
-   <bound-workflow workflow_id="workspace_folder_wf"/>
+  <type type_id="ScratchCardBatchesFolder">
+   <bound-workflow workflow_id="section_folder_wf"/>
+  </type>
+  <type type_id="ScratchCardBatch">
+   <bound-workflow workflow_id="section_folder_wf"/>
   </type>
  </bindings>
Index: /WAeUP_SRP/trunk/skins/waeup_custom/getContentInfo.py
===================================================================
--- /WAeUP_SRP/trunk/skins/waeup_custom/getContentInfo.py	(revision 439)
+++ /WAeUP_SRP/trunk/skins/waeup_custom/getContentInfo.py	(revision 440)
@@ -187,5 +187,5 @@
 info['url'] = utool.getUrlFromRpath(info['rpath'])
 
-info['title_or_id'] = proxy.title_or_id()
+info['title_or_id'] = proxy.id
 info['id'] = proxy.getId()
 try:
@@ -193,5 +193,8 @@
 except AttributeError:
     raise AttributeError, 'invalid object: %s in %s' % (info['title_or_id'],
-                                                        info['rpath'])
+                                                             info['rpath'])
+except TypeError:
+    info['title'] = proxy.getContent().id
+
 info['icon'] = proxy.getIcon(relative_to_portal=1)
 info['type'] = proxy.getPortalTypeName()
@@ -227,5 +230,5 @@
         core = 'core'
         if not doc.core_or_elective:
-            core = elective
+            core = 'elective'
         info['core_or_elective'] = core
     info['time'] = doc.modified()
Index: /WAeUP_SRP/trunk/skins/waeup_default/waeup_document_create_do.py
===================================================================
--- /WAeUP_SRP/trunk/skins/waeup_default/waeup_document_create_do.py	(revision 439)
+++ /WAeUP_SRP/trunk/skins/waeup_default/waeup_document_create_do.py	(revision 440)
@@ -10,6 +10,9 @@
 from Products.CMFCore.utils import getToolByName
 
-id = datamodel.get('code').upper()
-datamodel.set('code',id)
+if type_name == "StudyLevel":
+    id = datamodel.get('code')
+else:
+    id = datamodel.get('code').upper()
+    datamodel.set('code',id)
 ##if not id:
 ##    id = 'my ' + type_name

Index: /WAeUP_SRP/trunk/__init__.py
===================================================================
--- /WAeUP_SRP/trunk/__init__.py	(revision 439)
+++ /WAeUP_SRP/trunk/__init__.py	(revision 440)
@@ -32,6 +32,6 @@
 from Products.WAeUP_SRP.Students import StudentClearance, addStudentClearance
 from Products.WAeUP_SRP.Students import StudentPersonal, addStudentPersonal
-from Products.WAeUP_SRP.Students import StudentDocuments, addStudentDocuments
-from Products.WAeUP_SRP.Students import Jamb, addJamb
+from Products.WAeUP_SRP.Students import ScratchCardBatch, addScratchCardBatch
+from Products.WAeUP_SRP.Students import ScratchCardBatchesFolder, addScratchCardBatchesFolder
 from Products.WAeUP_SRP.Students import StudyLevel, addStudyLevel
 from Products.WAeUP_SRP.Students import Semester, addSemester
@@ -58,6 +58,6 @@
     StudentClearance,
     StudentPersonal,
-    StudentDocuments,
-    Jamb,
+    ScratchCardBatch,
+    ScratchCardBatchesFolder,
     StudyLevel,
     Semester,
@@ -82,35 +82,36 @@
     addStudentClearance,
     addStudentPersonal,
-    addStudentDocuments,
-    addJamb,
+    addScratchCardBatch,
+    addScratchCardBatchesFolder,
     addStudyLevel,
     addSemester,
     )
 
-fti = (
-    {}, # University
-    {}, #AcademicsFolder
-    {}, #Certificate
-    {}, #CertificateCourse
-    {}, # Faculty
-    {}, # Department
-    {}, # Course
-    {}, # CourseTicket
-    {}, # CertificateCourse
-    {}, # AccoFolder
-    {}, # Accommodation
-    {}, # StudentsFolder,
-    {}, # Student,
-    {}, # StudentStudyCourse,
-    {}, # StudentAdmission,
-    {}, # StudentClearance,
-    {}, # StudentAdmission,
-    {}, # StudentClearance,
-    {}, # StudentPersonal,
-    {}, # StudentDocuments,
-    {}, # Jamb,
-    {}, # StudyLevel,
-    {}, # Semester,
-    )
+fti = [{} for t in range(len(contentConstructors))]
+##fti = (
+##    {}, # University
+##    {}, #AcademicsFolder
+##    {}, #Certificate
+##    {}, #CertificateCourse
+##    {}, # Faculty
+##    {}, # Department
+##    {}, # Course
+##    {}, # CourseTicket
+##    {}, # CertificateCourse
+##    {}, # AccoFolder
+##    {}, # Accommodation
+##    {}, # StudentsFolder,
+##    {}, # Student,
+##    {}, # StudentStudyCourse,
+##    {}, # StudentAdmission,
+##    {}, # StudentClearance,
+##    {}, # StudentAdmission,
+##    {}, # StudentClearance,
+##    {}, # StudentPersonal,
+##    {}, # ScratchCardBatch,
+##    {}, # ScratchCardBatchesFolder,
+##    {}, # StudyLevel,
+##    {}, # Semester,
+##    )
 
 registerDirectory('skins', globals())